(this.webpackJsonpstreamlit_confetti=this.webpackJsonpstreamlit_confetti||[]).push([[0],{18:function(e,t,n){e.exports=n(25)},25:function(e,t,n){"use strict";n.r(t);var a=n(6),r=n.n(a),o=n(15),c=n.n(o),i=n(5),l=n(0),s=n(1),u=n(2),d=n(3),m=n(13),f=n(17);function h(){for(var e=window.parent.document.body,t=e.getElementsByTagName("canvas"),n=0;n<t.length;n++)try{e.removeChild(t[n])}catch(a){}}function p(){var e=document.createElement("canvas");return e.style.position="fixed",e.style.width="100%",e.style.height="100%",e.style.top="0",e.style.left="0",e.style.zIndex="1000",e.style.pointerEvents="none",window.parent.document.body.appendChild(e),e}var v=function(e){Object(u.a)(n,e);var t=Object(d.a)(n);function n(){var e;Object(s.a)(this,n);for(var a=arguments.length,r=new Array(a),o=0;o<a;o++)r[o]=arguments[o];return(e=t.call.apply(t,[this].concat(r))).render=function(){var t=e.props.args.emojis;if(h(),null!==t){var n,a=p(),r=new f.a({canvas:a}),o=Object(i.a)(t);try{for(o.s();!(n=o.n()).done;){var c=n.value,l=Math.round(100*c.score*1.5);r.addConfetti({emojis:[c.emoji],emojiSize:Math.min(100,Math.max(50,l)),confettiNumber:Math.min(100,Math.max(10,l))})}}catch(s){o.e(s)}finally{o.f()}}return""},e}return Object(l.a)(n)}(m.a),y=Object(m.b)(v);c.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(y,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.cc7c0cde.chunk.js.map